@@ -181,7 +181,7 @@ class PTWorkstationsSerializer(NetBoxModelSerializer):
 
     class Meta:
         model = PTWorkstations
-        fields = ('id', 'url', 'display', 'name', 'description'
+        fields = ('id', 'url', 'display', 'name', 'description',
                   'CN', 'DistinguishedName', 'ad_guid', 'ad_description')
 
 
@@ -191,7 +191,7 @@ class NestedPTWorkstationsAssignmentSerializer(WritableNestedSerializer):
 
     class Meta:
         model = PTWorkstations
-        fields = ('id', 'slug', 'url', 'display', 'name', 'description'
+        fields = ('id', 'slug', 'url', 'display', 'name', 'description',
                   'CN', 'DistinguishedName', 'ad_guid', 'ad_description')
 
 
